@@ -1,8 +1,8 @@
 __author__		= "Justin Wilson"
-__copyright__	= "Copyright 2011, Justin Wilson"
-__credits__		= ["Justin Wilson", "Eber Irigoyen", "Corey McKinnon"]
+__copyright__	= "Copyright 2012, Justin Wilson"
+__credits__		= ["Justin Wilson",]
 __license__		= "Simplified BSD License"
-__version__		= "0.1.6"
+__version__		= "0.1.7"
 __maintainer__	= "Justin Wilson"
 __email__		= "justinwilson1@gmail.com"
 __status__		= "Alpha"
